@@ -20,8 +20,6 @@
 #' \doi{10.1016/j.foodqual.2018.09.006}
 #' 
 #' @examples
-#' data(bread)
-#' 
 #' # homogeneity index for the first 7 consumers on the first 6 attributes
 #' homogeneity(bread$cata[1:7,,1:6])
 homogeneity <- function(X, oneI = FALSE, oneM = FALSE){
@@ -131,7 +129,6 @@ homogeneity <- function(X, oneI = FALSE, oneM = FALSE){
 #' \doi{10.1016/j.foodqual.2022.104564}.
 #' 
 #' @examples
-#' data(bread)
 #' evaluateClusterQuality(bread$cata[1:8,,1:5], M = rep(1:2, each = 4))
 evaluateClusterQuality <- function(X, M, alpha = .05, M.order = NULL, 
                        quiet = FALSE, digits = getOption("digits"), ...){
@@ -179,23 +176,24 @@ evaluateClusterQuality <- function(X, M, alpha = .05, M.order = NULL,
                                            dimnames(X.bc)[[4]],
                                            c("lower.tail", "upper.tail")))
   for(g in 1:G){
-      Mg <- which(M == gID[g])
-      g.pp.M.two1tail[g,,,1] <- 
-        mapply(.withinGroupDiscrim.signif,
-               b = c(apply(array(X.bc[Mg, , 1, ], c(length(Mg), nJJ, nM)), 
-                           2:3, sum)), 
-               c = c(apply(array(X.bc[Mg, , 2, ], c(length(Mg), nJJ, nM)), 
-                                 2:3, sum)),
-               MoreArgs = list(alternative = "l", alpha = alpha/2))
+    Mg <- which(M == gID[g])
+    g.pp.M.two1tail[g,,,1] <- 
+      mapply(.withinGroupDiscrim.signif,
+             b = c(apply(array(X.bc[Mg, , 1, ], c(length(Mg), nJJ, nM)), 
+                         2:3, sum)), 
+             c = c(apply(array(X.bc[Mg, , 2, ], c(length(Mg), nJJ, nM)), 
+                         2:3, sum)),
+             MoreArgs = list(alternative = "l", alpha = alpha/2))
     g.pp.M.two1tail[g,,,2] <- 
       mapply(.withinGroupDiscrim.signif,
              b = c(apply(array(X.bc[Mg, , 1, ], c(length(Mg), nJJ, nM)), 
-                               2:3, sum)), 
-                   c = c(apply(array(X.bc[Mg, , 2, ], c(length(Mg), nJJ, nM)), 
-                                     2:3, sum)),
-                         MoreArgs = list(alternative = "g", alpha = alpha/2))
+                         2:3, sum)), 
+             c = c(apply(array(X.bc[Mg, , 2, ], c(length(Mg), nJJ, nM)), 
+                         2:3, sum)),
+             MoreArgs = list(alternative = "g", alpha = alpha/2))
     gMat[g,1] <- length(Mg)
-    gMat[g,2] <- getb(X.bc[Mg,,1,], X.bc[Mg,,2,], 
+    gMat[g,2] <- getb(X.bc[Mg,,1,, drop=FALSE], 
+                      X.bc[Mg,,2,, drop=FALSE], 
                       oneI = ifelse(length(Mg)==1, TRUE, FALSE), 
                       oneM = ifelse(nM==1, TRUE, FALSE))
     gMat[g,3] <- mean(X[Mg,,])
@@ -215,9 +213,11 @@ evaluateClusterQuality <- function(X, M, alpha = .05, M.order = NULL,
   #ggSaltonMat <- matrix(NA, nrow=G, ncol=G)
   if(G>1){
     for(gg1 in 2:nrow(ggMat)){
-      g1.data <- toMatrix(array(X[which(M==gID[gg1]),,], c(length(which(M==gID[gg1])), nJ, nM)), 
-                          oneI = ifelse(length(which(M==gID[gg1]))==1, TRUE, FALSE), 
-                          oneM = ifelse(nM==1, TRUE, FALSE))
+      g1.data <- toMatrix(array(X[which(M==gID[gg1]),,, drop=FALSE], 
+                                c(length(which(M==gID[gg1])), nJ, nM))#, 
+                         # oneI = ifelse(length(which(M==gID[gg1]))==1, TRUE, FALSE), 
+                         # oneM = ifelse(nM==1, TRUE, FALSE)
+                         )
       g1.aggr <- stats::aggregate(g1.data[,-c(1,2)], 
                            list(g1.data[,2]), sum)[,-1]
       g1.prop <- as.matrix(g1.aggr / length(which(M==gID[gg1])))
@@ -235,9 +235,11 @@ evaluateClusterQuality <- function(X, M, alpha = .05, M.order = NULL,
         this.denom <- prod(dim(g.pp.M.two1tail)[-1])
         ggMat[gg1, gg2] <- 100*this.num/this.denom
         # RV
-        g2.data <- toMatrix(array(X[which(M==gID[gg2]),,], c(length(which(M==gID[gg2])), nJ, nM)), 
-                            oneI = ifelse(length(which(M==gID[gg2]))==1, TRUE, FALSE), 
-                            oneM = ifelse(nM==1, TRUE, FALSE))
+        g2.data <- toMatrix(array(X[which(M==gID[gg2]),,, drop=FALSE], 
+                                  c(length(which(M==gID[gg2])), nJ, nM))#, 
+                            #oneI = ifelse(length(which(M==gID[gg2]))==1, TRUE, FALSE), 
+                            #oneM = ifelse(nM==1, TRUE, FALSE)
+                            )
         g2.aggr <- stats::aggregate(g2.data[,-c(1,2)], 
                              list(g2.data[,2]), sum)[,-1]
         g2.prop <- as.matrix(g2.aggr / length(which(M==gID[gg2])))
